package com.qryord.project.master.model.service.impl;

import com.qryord.common.utils.DateUtils;
import com.qryord.common.utils.text.Convert;
import com.qryord.project.master.model.domain.Model;
import com.qryord.project.master.model.mapper.ModelMapper;
import com.qryord.project.master.model.service.IModelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 商品型号Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-08-06
 */
@Service
public class ModelServiceImpl implements IModelService 
{
    @Autowired
    private ModelMapper modelMapper;

    /**
     * 查询商品型号
     * 
     * @param id 商品型号主键
     * @return 商品型号
     */
    @Override
    public Model selectModelById(Long id)
    {
        return modelMapper.selectModelById(id);
    }

    /**
     * 查询商品型号列表
     * 
     * @param model 商品型号
     * @return 商品型号
     */
    @Override
    public List<Model> selectModelList(Model model)
    {
        return modelMapper.selectModelList(model);
    }

    /**
     * 新增商品型号
     * 
     * @param model 商品型号
     * @return 结果
     */
    @Override
    public int insertModel(Model model)
    {
        model.setCreateTime(DateUtils.getNowDate());
        return modelMapper.insertModel(model);
    }

    /**
     * 修改商品型号
     * 
     * @param model 商品型号
     * @return 结果
     */
    @Override
    public int updateModel(Model model)
    {
        model.setUpdateTime(DateUtils.getNowDate());
        return modelMapper.updateModel(model);
    }

    /**
     * 批量删除商品型号
     * 
     * @param ids 需要删除的商品型号主键
     * @return 结果
     */
    @Override
    public int deleteModelByIds(String ids)
    {
        return modelMapper.deleteModelByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除商品型号信息
     * 
     * @param id 商品型号主键
     * @return 结果
     */
    @Override
    public int deleteModelById(Long id)
    {
        return modelMapper.deleteModelById(id);
    }
}
